function n_E = lat_long2n_E(latitude,longitude)
% lat_long2n_E Converts latitude and longitude to n-vector.
%   n_E = lat_long2n_E(latitude,longitude) 
%   n-vector (n_E) is calculated from (geodetic) latitude and longitude.
%
%   IN:
%   latitude:  [rad]     Geodetic latitude
%   longitude: [rad]
%
%   OUT:
%   n_E:       [no unit] n-vector decomposed in E (3x1 vector)
%
%   The function also accepts vectors (1xm) with lat and long, then a 3xm 
%   matrix of n-vectors is returned.
%
%   See also n_E2lat_long.


%   This file is part of NavLab and is available from www.navlab.net/nvector
%
%   The content of this file is based on the following publication:
%
%   Gade, K. (2010). A Nonsingular Horizontal Position Representation, The Journal 
%   of Navigation, Volume 63, Issue 03, pp 395-417, July 2010. 
%   (www.navlab.net/Publications/A_Nonsingular_Horizontal_Position_Representation.pdf)
%
%   This paper should be cited in publications using this file.
%
%   Copyright (c) 2015, Norwegian Defence Research Establishment (FFI)
%   All rights reserved.
%
%   Redistribution and use in source and binary forms, with or without 
%   modification, are permitted provided that the following conditions are met:
%
%   1. Redistributions of source code must retain the above publication 
%   information, copyright notice, this list of conditions and the following disclaimer.
%
%   2. Redistributions in binary form must reproduce the above publication 
%   information, copyright notice, this list of conditions and the following disclaimer 
%   in the documentation and/or other materials provided with the distribution.
%
%   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
%   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED 
%   TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
%   PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS 
%   BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
%   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
%   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
%   INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
%   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
%   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF 
%   THE POSSIBILITY OF SUCH DAMAGE.

% Originated: 1999.02.23 Kenneth Gade, FFI
% Modified:   2015.02.20 Kenneth Gade, FFI: Added possibility of using alternative E axes
%


% Equation (3) from Gade (2010):
n_E=R_Ee'*[sin(latitude) % R_Ee selects correct E-axes, see R_Ee.m for details
    sin(longitude).*cos(latitude)
    -cos(longitude).*cos(latitude)];
